<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'mega_tour_pro_blog_section', array(
	'title'             => esc_html__( 'Blog','mega-tour-pro' ),
	'description'       => esc_html__( 'Blog Section options.', 'mega-tour-pro' ),
	'panel'             => 'mega_tour_pro_front_page_panel',
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

// blog sub title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[blog_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_blog_section',
	'type'				=> 'text',
	'active_callback' 	=> 'mega_tour_pro_is_blog_default_design_enable',
) );

// blog title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_blog_section',
	'active_callback' 	=> 'mega_tour_pro_is_blog_title_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[blog_title]', array(
		'selector'            => 'div#blog-header h2',
		'settings'            => 'mega_tour_pro_theme_options[blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_blog_title_partial',
    ) );
}

// blog Description setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[blog_description]', array(
	'label'           	=> esc_html__( 'Description', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_blog_section',
	'active_callback' 	=> 'mega_tour_pro_is_blog_business_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[blog_description]', array(
		'selector'            => '#business-latest-posts .business-section-header p',
		'settings'            => 'mega_tour_pro_theme_options[blog_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_blog_description_partial',
    ) );
}

// blog btn title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[blog_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_blog_section',
	'active_callback' 	=> 'mega_tour_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[blog_btn_title]', array(
		'selector'            => '#blog-read-more a.more-link',
		'settings'            => 'mega_tour_pro_theme_options[blog_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_blog_btn_title_partial',
    ) );
}

// blog btn url setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[blog_btn_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_blog_section',
	'active_callback' 	=> 'mega_tour_pro_is_blog_default_design_enable',
	'type'				=> 'url',
) );

// Blog Social menu enable control and setting

$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_social_menu_enable]', array(
	'default'			=> 	$options['blog_social_menu_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[blog_social_menu_enable]', array(
	'label'             => esc_html__( 'Enable Social menu', 'mega-tour-pro' ),
	'description'       => sprintf( '%1$s <a class="topbar-menu-trigger" href="#"> %2$s </a> %3$s', esc_html__( 'Note: To show social menu.', 'mega-tour-pro' ), esc_html__( 'Click Here', 'mega-tour-pro' ), esc_html__( 'to create menu', 'mega-tour-pro' ) ),
	'section'           => 'mega_tour_pro_blog_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
	'active_callback' 	=> 'mega_tour_pro_is_blog_design_enable',
) ) );


// Blog content type control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_pro_is_blog_section_enable',
	'choices'			=> mega_tour_pro_blog_content_type(),
) );

// Blog post number control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_count]', array(
	'default'          	=> $options['blog_count'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_number_range',
	'validate_callback' => 'mega_tour_pro_validate_blog_count',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[blog_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'mega-tour-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_section',
	'active_callback'   => 'mega_tour_pro_is_blog_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['blog_count']; $i++ ) :
	// Blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[blog_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_blog_section',
		'choices'			=> mega_tour_pro_page_choices(),
		'active_callback'	=> 'mega_tour_pro_is_blog_section_content_page_enable',
	) ) );

	// Blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[blog_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_blog_section',
		'choices'			=> mega_tour_pro_post_choices(),
		'active_callback'	=> 'mega_tour_pro_is_blog_section_content_post_enable',
	) ) );

endfor;

// Add Blog dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[blog_content_trip_types]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Category_Control( $wp_customize,'mega_tour_pro_theme_options[blog_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'mega_tour_pro_is_blog_section_content_trip_types_enable'
) ) );

// Add Blog dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[blog_content_activity]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Category_Control( $wp_customize,'mega_tour_pro_theme_options[blog_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'mega_tour_pro_is_blog_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[blog_content_destination]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Category_Control( $wp_customize,'mega_tour_pro_theme_options[blog_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'mega_tour_pro_is_blog_section_content_destination_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-tour-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_blog_section_content_category_enable'
) ) );


// Add dropdown categories setting and control.
$wp_customize->add_setting( 'mega_tour_pro_theme_options[blog_category_exclude]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Category_Control( $wp_customize,'mega_tour_pro_theme_options[blog_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'mega-tour-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_blog_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'mega_tour_pro_is_blog_section_content_recent_enable'
) ) );
