<?php
/**
 *
 * @package Mega Tour Pro
 * @since Mega Tour Pro 1.0
 */

if ( ! class_exists( 'Mega_Tour_Pro_About_Us_Widget' ) ) :

	/**
	 * Adds Tp image widget.
	 */
	class Mega_Tour_Pro_About_Us_Widget extends WP_Widget {

		/**
		 * Register widget with WordPress.
		 */
		public function __construct() {
			$widget_ops = array(
				'classname'   => 'widget_about',
				'description' => esc_html__( 'An widget to upload About Content and images in footer.', 'mega-tour-pro' ),
			);
			parent::__construct( 'widget_about', esc_html__('TP: About Us','mega-tour-pro'), $widget_ops );
		}

		/**
		 * Front-end display of widget.
		 *
		 * @see WP_Widget::widget()
		 *
		 * @param array $args     Widget arguments.
		 * @param array $instance Saved values from database.
		 */
		public function widget( $args, $instance ) {
            extract( $args);
            $title = apply_filters( 'widget_title', $instance['title'] );
            $quote   			=  ! empty( $instance['quote'] ) ?  $instance['quote'] : '';
            $description   	    =  ! empty( $instance['description']  ) ? $instance['description'] : '';
            $btn_label   	    =  ! empty( $instance['btn_label'] ) ? $instance['btn_label'] : '';
            $btn_url   	        =  ! empty( $instance['btn_url'] ) ? $instance['btn_url'] : '';

			echo $args['before_widget'];
				if ( ! empty( $title ) ) {
					echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
				}
			?>
	            <div class="textwidget">
                    <?php if(! empty($quote)){ ?>
                        <p style="color: #f38625; font-size: 22px; font-style: italic;"><?php echo esc_html($quote); ?></p>
                    <?php }
                    if(! empty($description)){ ?>
                        <p><?php echo wp_kses_post($description); ?></p>
                    <?php }
                    if(! empty($btn_label) && ! empty($btn_url)) { ?>
                        <p><a href="<?php echo esc_url($btn_url);?>" style="font-size: 18px; color: #29bd33;"><?php echo esc_html($btn_label); ?></a></p>
                    <?php } ?>
                </div><!-- .textwidget -->
        <?php
			echo $args['after_widget'];
		}

		/**
		 * Back-end widget form.
		 *
		 * @see WP_Widget::form()
		 *
		 * @param array $instance Previously saved values from database.
		 */
		public function form( $instance ) {
			// Defaults.
	        $instance = wp_parse_args( (array) $instance, array(
				'title'                	=>  __('About us','mega-tour-pro'),
				'quote'                	=>  __('Explore the greatest tour of your life!!','mega-tour-pro'),
                'description'           =>  '',
                'btn_label'             =>  '',
                'btn_url'               =>  '#',
	      	) );

			$title                	= htmlspecialchars( $instance['title'] );
			$quote                	= htmlspecialchars( $instance['quote'] );
            $description           = htmlspecialchars( $instance['description'] );
			$btn_label         	= htmlspecialchars( $instance['btn_label'] );
			$btn_url             = isset( $instance['btn_url'] ) ? $instance['btn_url'] : '';
			?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title :', 'mega-tour-pro' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'quote' ) ); ?>"><?php esc_html_e( 'Quote :', 'mega-tour-pro' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'quote' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'quote' ) ); ?>" type="text" value="<?php echo esc_attr( $quote ); ?>">
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>"><?php esc_html_e( 'Description :', 'mega-tour-pro' ); ?></label>
				<textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'description' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'description' ) ); ?>"  value="<?php echo esc_attr( $description ); ?>"><?php echo wp_kses_post($description); ?></textarea>
			</p>

            <p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'btn_label' ) ); ?>"><?php esc_html_e( 'Button Label :', 'mega-tour-pro' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'btn_label' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'btn_label' ) ); ?>" type="text" value="<?php echo esc_attr( $btn_label ); ?>">
			</p>

		   <p>
		    	<label for="<?php echo esc_attr( $this->get_field_id( 'btn_url' ) ); ?>"><?php esc_html_e( 'Add link of Button Label', 'mega-tour-pro' ); ?>:</label>
		      	<input type="url" id="<?php echo esc_attr( $this->get_field_id( 'btn_url' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'btn_url' ), 'mega-tour-pro' ); ?>"  value="<?php echo esc_url( $btn_url ); ?>"/>
		   </p>

		<?php
		}

		/**
		 * Sanitize widget form values as they are saved.
		 *
		 * @see WP_Widget::update()
		 *
		 * @param array $new_instance Values just sent to be saved.
		 * @param array $old_instance Previously saved values from database.
		 *
		 * @return array Updated safe values to be saved.
		 */
		public function update( $new_instance, $old_instance ) {
            $instance = array();
			$instance['title']               = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ): '';
			$instance['quote']                = ( ! empty( $new_instance['quote'] ) ) ? sanitize_text_field( $new_instance['quote'] ): '';
            $instance['description']         = ( ! empty( $new_instance['description'] ) ) ? wp_kses_post( $new_instance['description'] ): '';
			$instance['btn_label']                = ( ! empty( $new_instance['btn_label'] ) ) ? sanitize_text_field( $new_instance['btn_label'] ): '';
			$instance['btn_url']            = ( ! empty( $new_instance['btn_url'] ) ) ? esc_url_raw( $new_instance['btn_url'] ): '';

            return $instance;
		}

	} // class tp_about_us_image_widget
endif;

function mega_tour_pro_register_widgets() {
    register_widget( 'Mega_Tour_Pro_About_Us_Widget' );
}
add_action( 'widgets_init', 'mega_tour_pro_register_widgets' );